@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2010 Werner Dittmann
+Copyright (c) 2010-2015 Werner Dittmann
 
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
@@ -78,7 +78,7 @@ OTHER DEALINGS IN THE SOFTWARE.
  * 
  */
 
-#include <ccrtp/crypto/skein.h>
+#include <crypto/skein.h>
 
 #ifdef _MSC_VER
 typedef signed __int8 int8_t;
