@@ -1,5 +1,6 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -773,7 +774,7 @@ size_t QueueRTCPManager::dispatchBYE(const std::string& reason)
     }
 
 
-    unsigned char buffer[BYE_BUFFER_LENGTH];
+    unsigned char buffer[BYE_BUFFER_LENGTH] = {0};
     // Build an empty RR as first packet in the compound.
         // TODO: provide more information if available. Not really
     // important, since this is the last packet being sent.
@@ -1088,7 +1089,7 @@ void QueueRTCPManager::setPRIVPrefix(Participant* part, const char* const value,
     memcpy(buf,value,len);
     buf[len] = '\0';
     ParticipantHandler::setPRIVPrefix(part,buf);
-    delete buf;
+    delete [] buf;
 }
 
 SDESItemType QueueRTCPManager::scheduleSDESItem()
