@@ -1,5 +1,6 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -41,9 +42,7 @@
 #include "private.h"
 #include <ccrtp/ext.h>
 
-#ifdef  CCXX_NAMESPACES
-namespace ost {
-#endif
+NAMESPACE_COMMONCPP
 
 RTPDuplex::RTPDuplex(const InetAddress &ia, tpport_t local, tpport_t remote) :
 RTPDataQueue(), UDPReceive(ia, local), UDPTransmit(ia, remote)
@@ -77,9 +76,7 @@ UDPSocket::Error RTPDuplex::connect(const InetHostAddress &ia, tpport_t port)
     return UDPTransmit::errSuccess;
 }
 
-#ifdef  CCXX_NAMESPACES
-}
-#endif
+END_NAMESPACE
 
 /** EMACS **
  * Local variables:
